#!/usr/bin/python
# -*- coding: UTF-8 -*-
 
import re

class CodeMatch:

	'匹配OC 代码的类'
	
	def __init__(self, name):
		self.name = name

		self.category_name = []
		self.class_name = []
		self.method_name = []
		self.property_name = []

	def getMatchCodeFile(self):
		# 打开文件
		fo = open(self.name, "r")
		for line in fo.readlines():
			class_name_match = re.match( r'^@implementation', line)
			if class_name_match:
				class_name_pattern = re.compile(r'^@implementation[ 	]*([A-Za-z0-9_]*)[ 	]*\(?.*')
				self.class_name = self.class_name  + class_name_pattern.findall(line) or []

				# category
				category_name_match = re.match(r'^@implementation[ 	]*.*\(.*\)', line)
				if category_name_match:
					category_name_pattern = re.compile(r'^@implementation[ 	]*[A-Za-z0-9_]*[ 	]*\([ 	]*([A-Za-z0-9_]*)[ 	]*\)')
					self.category_name = category_name_pattern.findall(line) or []

			method_name_match = re.match( r'^-[ 	]*\(', line)
			if method_name_match:
				method_name_pattern = re.compile(r'^-[	 ]*(.*)[ ]([A-Za-z0-9_]*)')
				self.method_name = self.method_name + [line]


			property_name_match = re.match(r'^@property', line)
			if property_name_match:
				property_name_pattern = re.compile(r'@property[ 	]*\(.*\)[ 	]*[A-Za-z0-9_]*[ 	\*]*([A-Za-z0-9_]*).*')
				self.property_name = self.property_name + property_name_pattern.findall(line) or []

		fo.close()

	def hasClass(self):
		return len(self.class_name) > 0
		
	def getClassName(self):
		return self.class_name

	def hasCategory(self):
		return len(self.category_name) > 0

	def getCategoryName(self):
		return self.category_name

	def hasMethod(self):
		return len(self.method_name) > 0

	def getMethod(self):
		return self.method_name

	def hasProperty(self):
		return len(self.property_name) > 0

	def getProperty(self):
		return self.property_name



#!/usr/bin/python
# -*- coding: UTF-8 -*-
 
import re
from .fileproc.FileProc import *;
from .codeproc.CodeMatch import *;
from .codeproc.CodeWrite import *;
from .codeproc.ObjectiveClass import *;



def ochandler(code_dir, output_dir):
	all_class_names = []
	all_property_names = []
	all_method_names = []

	mfile_list = search_file_recur_indir_with_ext(code_dir, [".m"])
	for filename in mfile_list:
		item = CodeMatch(filename)
		item.getMatchCodeFile()
		if item.hasClass():
			all_class_names = all_class_names + item.getClassName()

		if item.hasMethod():
			all_method_names = all_method_names + item.getMethod()

		if item.hasProperty():
			all_property_names = all_property_names + item.getProperty()

	# print all_class_names
	# print all_property_names

	hfile_list = search_file_recur_indir_with_ext(code_dir, [".h"])
	for filename in hfile_list:
		item = CodeMatch(filename)
		item.getMatchCodeFile()
		if item.hasProperty():
			all_property_names = all_property_names + item.getProperty()




	fCls = open(os.path.join(output_dir, "class_name.txt"), "w+")
	for ele in all_class_names:
		fCls.write(ele + '\n')
	fCls.close()


	fProperty = open(os.path.join(output_dir, "property_name.txt"), "w+")
	for ele in all_property_names:
		property_name_match = re.match( r'^[a-z]*[A-Z]{1}[a-zA-Z]*', ele)
		if property_name_match:
			fProperty.write(ele+ '\n')
	fProperty.close()




#!/usr/bin/python
# -*- coding: UTF-8 -*-

class ObjectiveClass:

	'OC 代码的类'
	
	def __init__(self, file_name, class_name):
		self.file_name = name
		self.class_name = class_name
		
		self.category  = None
		self.methods = []
		self.properties= []

	def isCategory(self):
		return self.category != None

	def hasProperties(self):
		return len(self.properties) > 0

	def hasMethods(self):
		return len(self.methods) > 0

	def setCategory(self, category):
		return self.category

	def addMethod(self, method):
		return self.methods.append(method)

	def addProperty(self, property):
		return self.properties.append(property)



#!/usr/bin/python
# -*- coding: UTF-8 -*-
 
# sys.path.append(os.path.dirname(__file__) +os.sep+'../')
class CodeWrite:
	
	'处理OC 代码的类'
	
	def __init__(self, name):
		self.name = name

	def fileName(self):
		# print  self.name
		return self.name

	def getFirstClassName(self):
		# print "Total Employee %d"
		return self.name

	def displayEmployee(self):
	 	# print "Name : "
		return self.name